import QtQuick 1.1

Item  {
    id: boardRow

    property variant values : [];
    property double cellSize : values.length>0 ? (width-20)/values.length : 0;

    Row {
        anchors.centerIn: parent;
        Repeater {
            model: boardRow.values.length

            Item {
                width: boardRow.cellSize
                height: boardRow.height-10

                Rectangle {
                    id: _rectangle
                    anchors {
                        fill: parent;
                        margins: 5
                    }

                    border {
                        width: 1
                        color: "#777777"
                    }

                    radius: 10

                    Text {
                        id: _text
                        anchors.centerIn: parent;
                        text: boardRow.values[index]+1;
                        font {
                            pixelSize: Math.min(parent.height, parent.width)
                        }
                    }
                }

                Gradient {
                    id: colorGradient
                    GradientStop { position: .1; color:"white"; }
                    GradientStop { position: .7; color: settings.colors[boardRow.values[index]]; }
                    GradientStop { position: .9; color:"white"; }

                }

                state: settings.style

                states: [
                    State {
                        name: "color"
                        PropertyChanges {
                            target: _rectangle
                            gradient: colorGradient
                        }
                        PropertyChanges {
                            target: _text
                            visible: false;
                        }
                    },
                    State {
                        name: "text"
                        PropertyChanges {
                            target: _rectangle
                            color: "#444444"
                        }
                        PropertyChanges {
                            target: _text
                            color: "#cccccc"
                            visible: true;
                        }
                    },
                    State {
                        name: "mixed"
                        PropertyChanges {
                            target: _rectangle
                            gradient: colorGradient
                        }
                        PropertyChanges {
                            target: _text
                            color: "black"
                            visible: true;
                        }
                    }


                ]
            }
        }
    }

    onValuesChanged: {
        console.log('board values changed to ' + values);
    }
}
