import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: dial
    property alias currentIndex : pathview.currentIndex

    PathView {
        id: pathview

        model: settings.nColors
        anchors.fill: parent
        clip: true

        path: mypath;
        preferredHighlightBegin: 0.5
        preferredHighlightEnd: 0.5

        delegate: Item {
            id: _item

            height: _text.height
            width: parent.width / scale
            scale: PathView.scale
            z: PathView.z;

            Rectangle {
                id: _rect

                anchors {
                    left: parent.left
                    right: parent.right
                    verticalCenter: parent.verticalCenter
                    margins: 10
                }
                height: Math.max(3*parent.height/settings.nColors, dial.height/3)
                border.width: 2
                radius: 10
                opacity: parent.scale;
            }

            Text {
                id: _text
                anchors.centerIn: parent
                text: index+1;
                font.pixelSize: Math.min(dial.height/3, _item.width/text.length)
            }

            Gradient {
                id: colorGradient
                GradientStop { position: .1; color:"white"; }
                GradientStop { position: .5; color: settings.colors[index]; }
                GradientStop { position: .9; color:"white"; }

            }

            state: settings.style
            states: [
                State {
                    name: "color"
                    PropertyChanges {
                        target: _rect
                        gradient: colorGradient
                    }
                    PropertyChanges {
                        target: _text
                        visible: false
                    }
                },
                State {
                    name: "text"
                    PropertyChanges {
                        target: _rect
                        color: "white"
                    }
                    PropertyChanges {
                        target: _text
                        visible: true
                    }
                },
                State {
                    name: "mixed"
                    PropertyChanges {
                        target: _rect
                        gradient: colorGradient
                    }
                    PropertyChanges {
                        target: _text
                        visible: true
                    }
                }

            ]

        }
    }

    Path {
        id: mypath

        startY: 0
        startX: dial.width / 2

        PathAttribute { name: "z"; value: 0 }
        PathAttribute { name: "scale"; value: 0.1 }
        PathPercent { value: 0.10 }

        PathLine { y: dial.height * 0.2; x: dial.width / 2;  }
        PathAttribute { name: "z"; value: 50 }
        PathAttribute { name: "scale"; value: .5 }
        PathPercent { value: 0.30 }

        PathLine { y: dial.height * 0.5; x: dial.width / 2;  }
        PathAttribute { name: "z"; value: 100 }
        PathAttribute { name: "scale"; value: 1.0 }

        PathLine { y: dial.height * 0.80; x: dial.width / 2;  }
        PathAttribute { name: "z"; value: 50 }
        PathAttribute { name: "scale"; value: .5 }
        PathPercent { value: 0.70 }

        PathLine { y: dial.height; x: dial.width / 2; }
        PathAttribute { name: "z"; value: 0 }
        PathAttribute { name: "scale"; value: 0.1 }
        PathPercent { value: 1 }
    }
}
