import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: page

    property variant game : [0,1,2,3,4,5];
    property int nCells : game.length
    property bool isFinished : false

    signal showSettings();
    signal showAbout();

    orientationLock: PageOrientation.LockPortrait;

    Rectangle {
        id: header

        gradient : Gradient {
            GradientStop {position: 0; color: "white"; }
            GradientStop {position: .9; color: "#ffff00" }
            GradientStop {position: 1; color: "black" }
        }

        anchors {
            left: parent.left;
            right: parent.right
            top: parent.top
        }

        height: appName.height+10

        Text {
            id: score
            anchors {
                verticalCenter: parent.verticalCenter
                left: parent.left
                leftMargin: 20
            }

            text: col.children.length>1 ? col.children.length + " attempts" :
                (col.children.length>0 ? "1 attempt" : "");

            font {
                pixelSize: 24
            }
        }

        Text {
            id: appName
            anchors {
                centerIn: parent
            }

            text: "LockCode"
            font {
                bold: true
                pixelSize: 24
            }
        }

        Text {
            id: timer
            anchors {
                verticalCenter: parent.verticalCenter
                right: parent.right
                rightMargin: 20
            }

            font {
                pixelSize: 24
            }

            Timer {
                id: _timer
                property variant startTime;

                interval: 200
                repeat: true;

                onTriggered: {
                    var elapsed = parseInt((new Date()-startTime)/1000);
                    var min = parseInt(elapsed / 60);
                    var sec = elapsed % 60;
                    timer.text = min + ":" + sec;
                }
            }

            function stop() {
                text = "";
                _timer.stop();
            }

            function pause() {
                _timer.stop();
            }

            function reset() {
                _timer.startTime = new Date();
                _timer.restart();
            }

        }

    }

    Rectangle {
        anchors {
            left: parent.left;
            right: parent.right
            top: header.bottom;
            bottom: selectorPanel.top
            bottomMargin: 10
        }

        radius: 10
        color: "#444444"

        Flickable {
            id: flickable

            clip: true;
            contentHeight: col.height
            interactive: contentHeight>height
            anchors {
                fill: parent
                // margins: 5
            }

            Column {
                id: col
                // spacing: 5
                anchors {
                    left: parent.left
                    right: parent.right
                }
            }

            onContentHeightChanged: {
                contentY = contentHeight-height
            }
        }

        ScrollDecorator {
            flickableItem: flickable
        }

    }

    Item {
        id: selectorPanel
        anchors {
            left: parent.left;
            right: parent.right
            bottom: parent.bottom
        }

        height: 300

        Item {
            anchors {
                right: parent.right
                left: selector.right
                top: parent.top
                bottom: parent.bottom
                leftMargin: 5
            }

            Button{
                anchors {
                    top: parent.top
                    bottom: settingsBtt.top

                    left: parent.left
                    right:parent.right
                }

                iconSource: "unlock.png"
                onClicked: {
                    if (isFinished) {
                        // restart
                        page.newgame();
                        return;
                    }

                    if ( col.children.length===0 ) {
                        // start timer
                        timer.reset();
                    }

                    page.evaluate();
                }
            }

            /*
            Button {
                id: settingsBtt
                anchors {
                    bottom: parent.bottom
                    left: parent.left
                    right:parent.right
                }
                height: 70
                iconSource: "settings.png"
                onClicked: showSettings();
            }
            */

            Item {
                id: settingsBtt
                anchors {
                    bottom: parent.bottom
                    left: parent.left
                    right:parent.right
                }
                height: 70

                Image {
                    anchors {
                        fill: parent;
                        margins: mouse.pressed ? 10 : 5
                    }

                    source: "settings.png"
                    smooth: true;
                    fillMode: Image.PreserveAspectFit

                    MouseArea {
                        id: mouse
                        anchors.fill: parent
                        onClicked: showSettings();
                        onPressAndHold: showAbout();
                    }
                }
            }
        }

        Component {
            id: template
            MMRow {
                anchors {
                    left: parent.left;
                    right: parent.right;
                }

                height: 75
            }
        }

        Selector {
            id: selector
            nCells: page.nCells;

            anchors {
                rightMargin: 100
                left: parent.left
                right: parent.right
                top: parent.top
                bottom: parent.bottom
            }
        }

    }

    function newgame() {
        timer.stop();

        var c;
        for ( c=col.children.length-1; c>=0; c-- ) col.children[c].destroy();

        var pool = new Array();
        for ( c=0; c<settings.nColors; c++ ) pool.push(c);

        var newgame = new Array();
        for ( c=0; c<settings.nPositions; c++ ) {
            var index = Math.floor(Math.random()*pool.length);
            var value = pool[index];

            if ( !settings.withDuplicates || newgame.indexOf(value)>=0 ) {
                // remove from pool
                pool.splice(index,1);
            }

            newgame.push(value);
        }

        page.isFinished = false;
        page.game = newgame;
        selector.reset();
        console.log("new game: " + newgame);
    }

    function evaluate() {
        var selection = selector.getSelection();
        var score = new Array();
        var c;
        var blacks = 0;
        var whites = 0;

        // blacks
        var c1 = new Array();
        var c2 = new Array();
        for ( c=0; c<selection.length; c++ ) {
            if ( selection[c]==page.game[c] ) {
                score.push(2);
                blacks ++;
                continue;
            }
            c1.push(page.game[c]);
            c2.push(selection[c]);
        }

        if (blacks==game.length) {
            // edn of game
            isFinished = true;
            timer.pause();
            console.log("end of game");
        }

        // whites
        for (c=0; c<c1.length; c++) {
            var index = c2.indexOf(c1[c]);
            if ( index<0 ) continue;
            whites++;
            score.push(1);
            c2.splice(index,1);
        }

        // blanks
        while ( score.length<page.game.length ) score.push(0);

        var obj = template.createObject(col);
        obj.rowNumber = col.children.length
        obj.selection = selection;
        obj.score = score;
    }

}
