import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: settingsPage

    property int skinIndex;
    property int presetIndex;
    property alias nColors : colors.value
    property alias nPositions : slots.value
    property alias withDuplicates : allowDoubles.checked

    signal done();

    orientationLock: PageOrientation.LockPortrait;

    tools: ToolBarLayout {
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: {
                done();
            }
        }
    }

    Flickable {
        anchors.fill: parent
        contentHeight: column.height
        clip: true

        Column {
            id: column

            anchors {
                left: parent.left
                right: parent.right
            }

            spacing: 10

            Column {
                anchors {
                    left: parent.left
                    right: parent.right
                }

                Label {
                    x: 10
                    text: "Skin"
                }

                ButtonColumn {
                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    exclusive: false

                    Button {
                        text: "Digits"
                        checked: skinIndex==0
                        onClicked:  skinIndex = 0;
                    }

                    Button {
                        text: "Colors"
                        checked: skinIndex==1
                        onClicked:  skinIndex = 1;
                    }

                    Button {
                        text: "Mixed"
                        checked: skinIndex==2
                        onClicked:  skinIndex = 2;
                    }
                }
            }

            Column {
                anchors {
                    left: parent.left
                    right: parent.right
                }

                Label {
                    x: 10
                    text: "Preset"
                }

                ButtonColumn {
                    anchors {
                        left: parent.left
                        right: parent.right
                    }

                    exclusive: false
                    Button {
                        text: "Beginner (2 colors, 2 slots)"
                        checked: presetIndex==0
                        onClicked:  {
                            presetIndex = 0;
                            nColors = 2;
                            nPositions = 2;
                        }
                    }
                    Button {
                        text: "Easy (4 colors, 3 slots)"
                        checked: presetIndex==1
                        onClicked:  {
                            presetIndex = 1;
                            nColors = 4;
                            nPositions = 3;
                        }
                    }
                    Button {
                        text: "Classic (6 colors, 4 slots)"
                        checked: presetIndex==2
                        onClicked:  {
                            presetIndex = 2;
                            nColors = 6;
                            nPositions = 4;
                        }

                    }
                    Button {
                        text: "Challenging (8 colors, 6 slots)"
                        checked: presetIndex==3
                        onClicked:  {
                            presetIndex = 3;
                            nColors = 8;
                            nPositions = 6;
                        }
                    }
                    Button {
                        text: "Hard (10 colors, 5 slots)"
                        checked: presetIndex==4
                        onClicked:  {
                            presetIndex = 4;
                            nColors = 10;
                            nPositions = 5;
                        }
                    }
                    Button {
                        text: "Custom"
                        checked: presetIndex==5
                        onClicked:  {
                            presetIndex = 5;
                            colors.value = nColors;
                            slots.value = nPositions;
                        }
                    }
                }
            }

            Column {
                anchors {
                    left: parent.left
                    right: parent.right
                }
                visible: presetIndex==5

                Label {
                    x: 10
                    text: "Number of Slots"
                }

                Row {
                    Slider {
                        id: slots
                        minimumValue: 2
                        maximumValue: 6
                        stepSize: 1
                        /*
                        onValueChanged:  {
                            if ( presetIndex!=5 ) return;
                            nPositions = value;
                        }
                        */
                    }

                    TextField {
                        readOnly: true;
                        text: slots.value
                        maximumLength: 2
                        width: 70
                    }
                }
            }

            Column {
                anchors {
                    left: parent.left
                    right: parent.right
                }
                visible: presetIndex==5

                Label {
                    x: 10
                    text: "Number of Colors"
                }

                Row {
                    Slider {
                        id: colors
                        minimumValue: slots.value
                        maximumValue: 10
                        stepSize: 1

                        /*
                        onValueChanged: {
                            if ( presetIndex!=5 ) return;
                            nColors = value;
                        }
                        */
                    }
                    TextField {
                        readOnly: true;
                        text: colors.value
                        maximumLength: 2
                        width: 70
                    }
                }
            }

            CheckBox {
                x: 10
                id: allowDoubles
                text: "Allow Doubles"
                //checked: withDuplicates
                //onCheckedChanged: withDuplicates = checked;
            }

        }
    }
}
