import QtQuick 1.1
import com.nokia.meego 1.0
import "settings.js" as Settings;

PageStackWindow {
    id: appWindow

    initialPage: mainPage

    QtObject {
        id: settings

        property variant colors: ["blue", "red", "green", "yellow", "orange", "cyan", "pink", "purple", "gray", "maroon"];

        property int presetIndex : 2; // 6colors, 4slots
        property int nPositions : 4;
        property int nColors : 6;
        property bool withDuplicates : false

        property int skinIndex : 0; // numbers ("text")
        property string style: "text"
        property string scoreImage : "lock"
    }

    MainPage {
        id: mainPage

        onShowSettings: {
            appWindow.pageStack.push(settingsPage.createObject(appWindow))
        }

        onShowAbout: {
            aboutDialog.open();
        }
    }

    Component {
        id: settingsPage

        SettingsPage {
            nColors: settings.nColors
            nPositions: settings.nPositions
            withDuplicates:  settings.withDuplicates
            presetIndex: settings.presetIndex
            skinIndex: settings.skinIndex

            onDone: {
                settings.skinIndex = skinIndex;
                switch (settings.skinIndex) {
                    case 0: // text
                        settings.style = "text";
                        settings.scoreImage = "lock"
                        break;
                    case 1: // color
                        settings.style = "color";
                        settings.scoreImage = "star"
                        break;
                    case 2: // mixed
                        settings.style = "mixed";
                        settings.scoreImage = "star"
                        break;
                }

                var changed = false;
                changed = settings.presetIndex !== presetIndex ||
                    settings.nColors !== nColors ||
                    settings.nPositions !== nPositions ||
                    settings.withDuplicates !== withDuplicates;

                if ( changed ) {
                    // new game?
                    // ...

                    settings.presetIndex = presetIndex;
                    settings.withDuplicates = withDuplicates;
                    settings.nPositions = nPositions;
                    settings.nColors = nColors;
                }

                Settings.Default.save(settings);

                /* if ( changed ) */ mainPage.newgame();
                appWindow.pageStack.pop();
            }
        }
    }

    QueryDialog {
        id: aboutDialog
        titleText: "Crochik LockCode"
        message: "(C) 2012 Crochik Software Solutions, LLC\n1.0.0"
    }

    Component.onCompleted: {
        theme.inverted =true;

        Settings.init();
        Settings.Default.load(settings);

        mainPage.newgame();
    }
}
