.pragma library

var Default = null;

function init(dbName, version, description) {
    Default = new Database(dbName, version, description);
    Default.debug = false;
}

// class
function Database(dbName, version, description) {
    this.name = !dbName ? "Settings" : dbName;
    this.version = !version ? "1.0" : version;
    this.description = !description ? "Settings" : description;
    this.create();
}

Database.prototype.create = function() {
    this.get().transaction(
        function(tx) {
            tx.executeSql('CREATE TABLE IF NOT EXISTS SETTINGS(NAME TEXT, VALUE TEXT)');
        }
    );
}

Database.prototype.get = function() {
    return openDatabaseSync(this.dbName, this.version, this.description, 1000000);
}


Database.prototype.load = function(container) {
    this.get().readTransaction(
        function(tx) {
            var rs = tx.executeSql('SELECT * FROM SETTINGS');
            for(var c = 0; c < rs.rows.length; c++) {
                var record = rs.rows.item(c);
                if ( this.debug ) console.log( "Load Setting " + record.NAME + "=" + record.VALUE);
                container[record.NAME] = record.VALUE;
            }
        }
    );
}

Database.prototype.save = function(container) {
    this.get().transaction(
        function(tx) {
            for ( var name in container ) {
                var value = container[name];
                switch (typeof value) {
                    case "function":
                    case "object":
                        if (this.debug) console.log("Skip Saving Setting: " + name + "(" + (typeof value) + ")");
                        value = null;
                        break;
                }

                tx.executeSql("DELETE FROM SETTINGS WHERE NAME=?", [ name ] );

                if (!value) continue;

                if ( this.debug ) console.log("Save Setting: " + name + "(" + (typeof value) + "): " + value);
                tx.executeSql('INSERT INTO SETTINGS(NAME,VALUE) VALUES(?, ?)', [ name, value ]);
            }
        }
    );
}
